@@ -1,13 +1,15 @@
 from __future__ import annotations
 
 import warnings
-from datetime import datetime
 from typing import TYPE_CHECKING
 
-from edc_appointment.form_validators import WindowPeriodFormValidatorMixin
+from django.utils.text import format_lazy
+from django.utils.translation import gettext_lazy as _
+from edc_appointment.form_validator_mixins import WindowPeriodFormValidatorMixin
 from edc_form_validators import INVALID_ERROR, FormValidator
 from edc_registration import get_registered_subject_model_cls
 from edc_utils import floor_secs, formatted_datetime, to_utc
+from edc_utils.date import to_local
 from edc_visit_tracking.modelform_mixins import get_related_visit
 
 from .crf_form_validator_mixins import CrfFormValidatorMixin
@@ -55,31 +57,23 @@ class CrfFormValidator(
     def dob(self):
         return self.registered_subject.dob
 
-    def get_consent_for_period_or_raise(self):
-        """Assert falls within a valid consent period
-
-        See also: modelform (self.get_consent_for_period_or_raise())
-        """
-        pass
-
     def validate_crf_report_datetime(self) -> None:
         if self.report_datetime:
             # falls within appointment's window period
             self.validate_crf_datetime_in_window_period()
-
-            # falls within a valid consent period
-            self.get_consent_for_period_or_raise()
-
             # not before consent date
-            if floor_secs(self.report_datetime) < floor_secs(self.consent_datetime):
+            report_datetime = to_utc(self.report_datetime)
+            consent_datetime = self.get_consent_datetime_or_raise(
+                report_datetime=report_datetime, fldname="report_datetime"
+            )
+            if floor_secs(report_datetime) < floor_secs(consent_datetime):
+                msg = _("Invalid. Cannot be before date of consent. Participant consented on")
+                formatted_date = formatted_datetime(to_local(consent_datetime))
+                err_message = format_lazy(
+                    "{msg} {formatted_date}", msg=msg, formatted_date=formatted_date
+                )
                 self.raise_validation_error(
-                    {
-                        self.report_datetime_field_attr: (
-                            "Invalid. Cannot be before date of consent. "
-                            "Participant consent on "
-                            f"{formatted_datetime(self.consent_datetime)}"
-                        )
-                    },
+                    {self.report_datetime_field_attr: err_message},
                     INVALID_ERROR,
                 )
 
@@ -96,8 +90,11 @@ class CrfFormValidator(
         try:
             return self.related_visit.appointment
         except AttributeError:
+            msg = _("is required")
+            verbose_name = self.related_visit._meta.verbose_name
             self.raise_validation_error(
-                f"{self.related_visit._meta.verbose_name} is required.", INVALID_ERROR
+                format_lazy("{verbose_name} {msg}.", msg=msg, verbose_name=verbose_name),
+                INVALID_ERROR,
             )
 
     @property
@@ -127,15 +124,6 @@ class CrfFormValidator(
         except AttributeError as e:
             raise CrfFormValidatorError(f"{e}. See {self.__class__}")
 
-    @property
-    def consent_datetime(self) -> datetime:
-        dt = (
-            get_registered_subject_model_cls()
-            .objects.get(subject_identifier=self.subject_identifier)
-            .consent_datetime
-        )
-        return to_utc(dt)
-
     def validate_datetime_against_report_datetime(self, field: str) -> None:
         """Datetime cannot be after report_datetime"""
         if (
@@ -145,7 +133,7 @@ class CrfFormValidator(
             > floor_secs(self.report_datetime)
         ):
             self.raise_validation_error(
-                {field: "Cannot be after report datetime"}, INVALID_ERROR
+                {field: _("Cannot be after report datetime")}, INVALID_ERROR
             )
 
     def validate_date_against_report_datetime(self, field: str) -> None:
@@ -156,7 +144,7 @@ class CrfFormValidator(
             and self.cleaned_data.get(field) > self.report_datetime.date()
         ):
             self.raise_validation_error(
-                {field: "Cannot be after report datetime"}, INVALID_ERROR
+                {field: _("Cannot be after report datetime")}, INVALID_ERROR
             )
 
     @property
