@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.db import models
+from django.utils.translation import gettext_lazy as _
 from edc_constants.choices import DOCUMENT_STATUS
 from edc_constants.constants import INCOMPLETE
 
@@ -22,14 +23,14 @@ class CrfStatusModelMixin(models.Model):
         max_length=25,
         choices=DOCUMENT_STATUS,
         default=get_crf_status_default,
-        help_text="If some data is still pending, flag this CRF as incomplete",
+        help_text=_("If some data is still pending, flag this CRF as incomplete"),
     )
 
     crf_status_comments = models.TextField(
-        verbose_name="Any comments related to status of this CRF",
+        verbose_name=_("Any comments related to status of this CRF"),
         null=True,
         blank=True,
-        help_text="for example, why some data is still pending",
+        help_text=_("for example, why some data is still pending"),
     )
 
     def update_crf_status_for_instance(self):
@@ -37,3 +38,4 @@ class CrfStatusModelMixin(models.Model):
 
     class Meta:
         abstract = True
+        indexes = []
