@@ -3,7 +3,7 @@ from typing import Optional
 from django.apps import apps as django_apps
 from edc_constants.constants import INCOMPLETE
 
-from .crf_status_model_mixin import CrfStatusModelMixin
+from .model_mixins import CrfStatusModelMixin
 from .update_crf_status_for_instance import update_crf_status_for_instance
 
 
